pub enum RegisterScalableTargetError {
ConcurrentUpdate(String),
InternalService(String),
LimitExceeded(String),
}Expand description
Errors returned by RegisterScalableTarget
Variants
ConcurrentUpdate(String)
Concurrent updates caused an exception, for example, if you request an update to an Application Auto Scaling resource that already has a pending update.
InternalService(String)
The service encountered an internal error.
LimitExceeded(String)
A per-account resource limit is exceeded. For more information, see Application Auto Scaling service quotas.
Implementations
Sourceimpl RegisterScalableTargetError
impl RegisterScalableTargetError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<RegisterScalableTargetError>